# -*- encoding: utf-8 -*-
'''
@File    :   requestModel.py
@Time    :   2020/01/30 11:22:59
@Author  :   chenjiusi 
'''
import json
import logging
from BearSki.CommonData import SkiGlobalData
import requests
from BearSki.keywords.DataTreating import BaseDataTreating
class RequestModelCommondKW(object):

  def __init__(self):
    self.logger=logging.getLogger("kw.RequestModelCommondKW")
    self.BASE_URL=SkiGlobalData().get_global_data('BASE_URL')
    self.MODEL_PATH=SkiGlobalData().get_global_data('MODEL_PATH')

  def run(self,jstr):
    self.logger.info("运行json：{0}".format(jstr))
    url = jstr['name']
    self.logger.info("url is :"+url)
    method=jstr['request']['method']
    headers_data = {}
    bdt=BaseDataTreating()
    h_ds=jstr['request']['headers']
    for hname in h_ds:
      # 使用通用数据替换方法替换消息头
      headers_data[hname]=bdt.treating(hname,h_ds[hname])
    print(headers_data)

    if method=='POST':
      # logger.info('in login！')
      post_data=jstr['request']['json']
      print(self.BASE_URL+url)
      r = requests.post(url=self.BASE_URL+url,headers=headers_data,json=post_data)   
      self.logger.info("response is : {0}".format(r))
      # logger.info("response is : {0}".format(r.text))
      # result=json.loads(r.text)
    # global jwt_access
    # jwt_access[login_user['username']]=result['data']['access']
    # if method=='GET':
    if method == 'GET':
      post_data=jstr['request']['params']
      print(self.BASE_URL+url)
      r = requests.get(url=self.BASE_URL+url,headers=headers_data,params=post_data)   
      self.logger.info("response is : {0}".format(r))
    return r


from BearSki.utils.arguments import runArg
import time
import os
class reportBody(object):
    ALLTEXTDEMO=u'''
    <!doctype html>
    <html lang="en">
      <head>
        <!-- Required meta tags -->
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <title>Hello, Bootstrap Table!</title>

        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
        <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.6.3/css/all.css" integrity="sha384-UHRtZLI+pbxtHCWp1t77Bi1L4ZtiqrqD80Kn4Z8NTSRyMA2Fd33n5dQ8lWUE00s/" crossorigin="anonymous">
        <link rel="stylesheet" href="https://unpkg.com/bootstrap-table@1.15.5/dist/bootstrap-table.min.css">
        <script src="https://code.jquery.com/jquery-3.3.1.min.js" integrity="sha256-FgpCb/KJQlLNfOu91ta32o/NMZxltwRo8QtmkMRdAu8=" crossorigin="anonymous"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js" integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" crossorigin="anonymous"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous"></script>
        <script src="https://unpkg.com/bootstrap-table@1.15.5/dist/bootstrap-table.min.js"></script>
      </head>
      <body>
      <div class="container">
        <div class="jumbotron jumbotron-fluid">
          <div class="container">
          <h1 class="display-4">BearSki 自动化测试报告</h1>
          <p class="lead"></p>
          <p class="lead">执行结果汇总:
    '''
    MIDBODY=u'''
        </div>
        </div>
        <h3>用例执行情况：</h3>
        <HR  align=left width=500 color=#987cb9 SIZE=1/>
        <div width=400>
        <table id="table"
        data-toolbar="#toolbar"
      data-search="true"
      data-show-refresh="true"
      data-show-toggle="true"
      data-show-fullscreen="true"
      data-show-columns="true"
      data-show-columns-toggle-all="true"
      data-detail-view="true"
      data-show-export="true"
      data-click-to-select="true"
      data-detail-formatter="detailFormatter"
      data-minimum-count-columns="2"
      data-show-pagination-switch="true"
      data-pagination="true"
      data-id-field="id"
      data-page-list="[10, 25, 50, 100, all]"
      data-show-footer="true"
        >
      <thead>
        <tr>
          <th data-field="id">ID</th>
          <th data-field="suitname">SUITNAME</th>
          <th data-field="casename">CASENAME</th>
          <th data-field="result">RESULT</th>
        </tr>
      </thead>
    </table>
    </div>
    </div>
    <script>

      var $table = $('#table')
      $(function() {
        var data = 
      '''
    ENDPART=u'''
        $table.bootstrapTable({data: data})
      })

    </script>
    <script>
      function detailFormatter(index, row) {
        var html = []
        $.each(row, function (key, value) {
          if(key=='message'){
            
            for(line in value){
                html.push('<p><b>' + value[line] + '</p>')
            }
              
            
            
          }
        
        })
        return html.join('')
      }
    </script>

      </body>
    </html>
    '''
    result_data=[]

    SUMMARYTEXT=u'''
    <span class="badge badge-success">Pass</span> &ensp;'''
    S1=u'''&ensp;
          <span class="badge badge-danger">Error</span> &ensp; '''
    S2=u''' &ensp;<span class="badge badge-warning">Failure</span>  &ensp;'''
    S3=u''' </p>
    '''
    summary_all=''
    report=''
    def __init__(self):
      self.rags=runArg()
    def add_summary(self,summary_data):
      # self.summary_data={'success':sd,'error':ed,'warning':wd}
      self.summary_all=self.SUMMARYTEXT+summary_data['success']+self.S2+summary_data['warning']+self.S1+summary_data['error']+self.S3
    
    def generate_report(self):
      self.report=self.ALLTEXTDEMO+self.summary_all+self.MIDBODY+str(self.result_data)+self.ENDPART
    
    def add_one_test_result(self,result_data):
      self.result_data.append(result_data)

    def writ_report(self):
      today_now=time.strftime("%Y%m%d_%H%M%S", time.localtime())
      (filepath, tempfilename) = os.path.split(self.rags.report_path)
      (filename, extension) = os.path.splitext(tempfilename)
      if not os.path.exists(filepath):
        os.makedirs(filepath)
      outfilename=self.rags.report_path
      if self.rags.report_add_time:
        outfilename=os.path.join(filepath,filename+"_"+today_now+extension)
      fo = open(outfilename, "w+",encoding='utf8')
      fo.write(self.report)
      fo.close
 
# if __name__ == '__main__':
  
#   rb=reportBody()
#   summary_test_data={'success':'1','error':'2','warning':'3'}
#   rb.add_summary(summary_test_data)
#   rdata={
#             'id': 0,
#             'casename': 'test 0',
#             'result': 'pass',
#             'message':['2019-09-27 14:36:48,954 INFO 开始执行测试',
#                       '2019-09-27 15:07:42,807 INFO in ask baidu!',
#                       '2019-09-27 15:08:02,280 INFO <Response [200]>',
#                       '2019-09-27 15:08:02,808 INFO Creating Session using : alias=baidu, url=http://www.baidu.com, headers={},                     cookies=None, auth=None, timeout=None, proxies=None, verify=False,                     debug=0 ',
#                       '2019-09-27 15:08:02,808 INFO Creating Session using : alias=baidu, url=http://www.baidu.com, headers={},                     cookies=None, auth=None, timeout=None, proxies=None, verify=False,                     debug=0 '
#             ]
#           }
#   rb.add_one_test_result(rdata)
#   rb.add_one_test_result(rdata)
#   rb.add_one_test_result(rdata)
#   rb.generate_report()
#   rb.writ_report()



import datetime
import io
import sys
import time
import unittest
from xml.sax import saxutils
from BearSki.report.ReportPage import  reportBody



TestResult = unittest.TestResult

class OutputRedirector(object):
    """ Wrapper to redirect stdout or stderr """
    def __init__(self, fp):
        self.fp = fp

    def write(self, s):
        self.fp.write(s)

    def writelines(self, lines):
        self.fp.writelines(lines)

    def flush(self):
        self.fp.flush()

stdout_redirector = OutputRedirector(sys.stdout)
stderr_redirector = OutputRedirector(sys.stderr)

class _TestResult(TestResult):
    
    def __init__(self, verbosity=1):
        TestResult.__init__(self)
        self.stdout0 = None
        self.stderr0 = None
        self.success_count = 0
        self.failure_count = 0
        self.error_count = 0
        self.verbosity = verbosity
        self.result = []

    def startTest(self, test):
        TestResult.startTest(self, test)
        # just one buffer for both stdout and stderr
        self.outputBuffer = io.StringIO()
        stdout_redirector.fp = self.outputBuffer
        stderr_redirector.fp = self.outputBuffer
        self.stdout0 = sys.stdout
        self.stderr0 = sys.stderr
        sys.stdout = stdout_redirector
        sys.stderr = stderr_redirector

    def complete_output(self):
        """
        Disconnect output redirection and return buffer.
        Safe to call multiple times.
        """
        if self.stdout0:
            sys.stdout = self.stdout0
            sys.stderr = self.stderr0
            self.stdout0 = None
            self.stderr0 = None
        return self.outputBuffer.getvalue()

    def stopTest(self, test):
        self.complete_output()

    def addSuccess(self, test):
        self.success_count += 1
        TestResult.addSuccess(self, test)
        output = self.complete_output()
        self.result.append(('pass', test, output, ''))
        
        
        
    def addError(self, test, err):
        self.error_count += 1
        TestResult.addError(self, test, err)
        _, _exc_str = self.errors[-1]
        output = self.complete_output()
        self.result.append(('error', test, output, _exc_str))
        

    def addFailure(self, test, err):
        self.failure_count += 1
        TestResult.addFailure(self, test, err)
        _, _exc_str = self.failures[-1]
        output = self.complete_output()
        self.result.append(('Failure', test, output, _exc_str))

class LocalReportRunner():
    """
    """
    DEFAULT_TITLE='BearSki 自动化测试报告'
    DEFAULT_DESCRIPTION=''
    def __init__(self, stream=sys.stdout, verbosity=1, title=None, description=None):
        self.stream = stream
        self.verbosity = verbosity
        if title is None:
            self.title = self.DEFAULT_TITLE
        else:
            self.title = title
        if description is None:
            self.description = self.DEFAULT_DESCRIPTION
        else:
            self.description = description
        self.startTime = datetime.datetime.now()


    def run(self, test):
        "Run the given test case or test suite."
        result = _TestResult(self.verbosity)
        test(result)
        self.stopTime = datetime.datetime.now()
        # print(result)
        self.generateReport(test, result)
        #print(sys.stderr, '\nTime Elapsed: %s' % (self.stopTime-self.startTime))
        return result

    def sortResult(self, result_list):
        # unittest does not seems to run in any particular order.
        # Here at least we want to group them together by class.
        rmap = {}
        classes = []
        for n,t,o,e in result_list:
            cls = t.__class__
            if not cls in rmap:
                rmap[cls] = []
                classes.append(cls)
            rmap[cls].append((n,t,o,e))
        r = [(cls, rmap[cls]) for cls in classes]
        return r


    def getlogMessage(self, message):
        mlist=message.split('\n')
        re=[]
        for mline in mlist:
            if mline != '':
                temp=mline
                line_list=temp.replace("]","$@$",3).split('$@$')
                if len(line_list)>=4:
                    timestr=line_list[0][1:]
                    loglevel=line_list[1][2:]
                    logname=line_list[2][2:]
                    message=line_list[3]
                    fline=self.timestr_style(timestr)+self.logleverl_style(loglevel)+self.logname_style(loglevel,saxutils.escape(logname))+self.message_style(loglevel,saxutils.escape(message))
                    re.append(fline)
                # elif len(line_list)==3 :
                #     timestr=line_list[0][1:]
                #     loglevel=line_list[1][2:]
                #     logname=line_list[2][2:]
                #     fline=self.timestr_style(timestr)+self.logleverl_style(loglevel)+self.logname_style(loglevel,logname)
                #     re.append(fline)
                else:
                    re.append(self.defalut_style(saxutils.escape(mline)))
        return re

    def generateReport(self, test, result):
        rb=reportBody()
        summary_test_data={'success':str(result.success_count),'error':str(result.error_count),'warning':str(result.failure_count)}
        rb.add_summary(summary_test_data)
        # print(result.result)
        
        for tid, (n,t,o,e) in enumerate(result.result):
            # print(o)
            fullname=t.id()
            casename=t.id().split('.')[-1]
            suitlong=len(fullname)-len(casename)-1
            rdata={'id': tid+1,
                'suitname':fullname[0:suitlong],
                'casename':casename,
                'result':self.result_style(n),
                'message':self.getlogMessage(o)}
            rb.add_one_test_result(rdata)
        rb.generate_report()
        rb.writ_report()
    def result_style(self,result):
        if result.lower()=='pass':
            return '<p class="text-success">pass</p>'
        elif result.lower()=='error':
            return '<p class="text-danger">error</p>'
        elif result.lower()=='false':
            return '<p class="text-dark">Failure</p>'
    def timestr_style(self,message):
        return '<a class="text-secondary">'+message+'&nbsp;</a>'
    
    def logleverl_style(self,level):
        if level.lower()=='info':
            return '<span class="badge badge-info">INFO</span>'
        elif level.lower()=='debug':
            return '<span class="badge badge-primary">DEBUG</span>'
        elif level.lower()=='error':
            return '<span class="badge badge-danger">ERROR</span>'
        elif level.lower()=='critical':
            return '<span class="badge badge-danger">CRITICAL</span>'
        elif level.lower()=='warning':
            return '<span class="badge badge-warning">WARNING</span>'
        else:
             return '<a class="text-primary">'+level+'</a>'

    def logname_style(self,level,name):
        if level.lower()=='error' or level.lower()=='critical':
            return '<a class="text-danger">&nbsp;['+name+']&nbsp;</a>'
        else:
            return  '<a class="text-primary">&nbsp;['+name+']&nbsp;</a>'
    
    def message_style(self,level,message):
        if level.lower()=='error' or level.lower()=='critical':
            return '<a class="text-danger">&nbsp;'+message+'</a>'
        else:
            return  '<a class="text-secondary">&nbsp;'+message+'</a>' 
    def defalut_style(self,message):
        return '<a class="text-secondary">'+message+'&nbsp;</a>'

        
       
        


# -*- encoding: utf-8 -*-
'''
@File    :   DataTreating.py
@Time    :   2020/02/02 16:10:07
@Author  :   chenjiusi 
'''
from BearSki.CommonData import SkiGlobalData

class BaseDataTreating(object):

  def __init__(self):
    self.sgd=SkiGlobalData()

  def treating(self,name,value):
    #先进行全局变量替换，再进行自定义方法替换
    revalue=self.treatingGlobalData(name,value)
    revalue=self.customTreating(name,revalue)
    return revalue

  def treatingGlobalData(self,name,value):
    revalue=SkiGlobalData().get_global_data(name)
    if revalue==None:
      return value
    else:
      return revalue

  def customTreating(self,name,value):
    return value
    ##全局替换，接口基本替换，用例替换，自定义替换 自定义数据处理


# -*- encoding: utf-8 -*-
'''
@File    :   ApiTestGui.py
@Time    :   2020/02/02 16:05:17
@Author  :   chenjiusi 
'''

from tkinter import *
from tkinter import ttk
from tkinter import filedialog
import hashlib
import time
import json
from BearSki.utils.hartool import HarTool

LOG_LINE_NUM = 0

class ApiTest_GUI(): 
    def __init__(self,init_window_name):

        self.init_window_name = init_window_name
        self.row_1=1
        self.row_2=2
        self.row_3=3
        self.row_4=7
        self.row_5=8
        
        self.row_rowspan_1=2
        self.row_rowspan_2=2
        
        self.column_1=0
        self.column_2=4
        self.column_row1_2=1
        self.column_row1_3=7
        self.column_row1_4=8
        self.column_row1_5=9

        self.row3_columnspan_1=4
        self.row3_columnspan_2=6
        self.column_2_columnspan=5

        self.pdx=5
        self.pady=5

        self.text_height=20

        self.HarTool= None

        

    #设置窗口
    def set_init_window(self):
        self.init_window_name.title("BearSki 用例生成工具 V 0.0.1")   #窗口名
        self.init_window_name.geometry('960x680')  #窗口大小设置
        self.init_window_name["bg"] = "#F5F5F5"
        self.init_window_name.grid_columnconfigure(0,weight=1)
        self.init_window_name.grid_rowconfigure(0,weight=1)

        #row 1
        self.init_data_label = Label(self.init_window_name, text="Har文件地址：")
        self.init_data_label.grid(row=self.row_1, column=self.column_1,sticky=N+W,padx=self.pdx,pady=self.pady)
        self.har_path_input=Entry(self.init_window_name,width=25)
        self.har_path_input.grid(row=self.row_1,column=self.column_row1_2,sticky=N+E,padx=self.pdx,pady=self.pady)

        self.get_har_text = ttk.Button(self.init_window_name, text="读取文件",command=self.openfiles)
        self.get_har_text.grid(row=self.row_1, column=self.column_2,sticky=N+W,padx=self.pdx,pady=self.pady)
        self.har_path_input2=Entry(self.init_window_name,width=15)
        self.har_path_input2.grid(row=self.row_1,column=self.column_row1_3,sticky=N+E,padx=self.pdx,pady=self.pady)

        self.put_one_request = ttk.Button(self.init_window_name, text="生成用例",command=self.createOneCase)  # 调用内部方法  加()为直接调用
        self.put_one_request.grid(row=self.row_1, column=self.column_row1_4,sticky=N+W,padx=self.pdx,pady=self.pady)
        self.put_all_request = ttk.Button(self.init_window_name, text="批量生成用例",command=self.createAllCase)  # 调用内部方法加()为直接调用
        self.put_all_request.grid(row=self.row_1, column=self.column_row1_5,sticky=N+W,padx=self.pdx,pady=self.pady)

        #row 2
        self.result_data_label = Label(self.init_window_name, text="请求目录:")
        self.result_data_label.grid(row=self.row_2, column=self.column_1, columnspan=self.row3_columnspan_1,sticky=N+W,padx=self.pdx,pady=self.pady)
        self.result_data_label1 = Label(self.init_window_name, text="发送的消息请求信息：")
        self.result_data_label1.grid(row=self.row_2, column=self.column_2,columnspan=self.row3_columnspan_2,sticky=N+W,padx=self.pdx,pady=self.pady)
        
        #row 3
        # # tree
        self.init_tree = ttk.Treeview(self.init_window_name, show="headings", columns=('col1'))
        self.init_tree.heading('col1', text='modelname')
        self.init_tree.column('col1', width=350, anchor='nw')
        self.init_tree.grid(row=self.row_3, column=self.column_1, rowspan=self.row_rowspan_1, columnspan=self.row3_columnspan_1,sticky=N+W,padx=self.pdx)

        self.result_data_Text = Text(self.init_window_name,height=self.text_height)  #处理结果展示
        self.result_data_Text.grid(row=self.row_3, column=self.column_2, rowspan=self.row_rowspan_1, columnspan=self.row3_columnspan_2,sticky=N+W,padx=self.pdx)

        #row 4
        self.log_label = Label(self.init_window_name, text="日志:")
        self.log_label.grid(row=self.row_4, column=self.column_1,sticky=N+W,padx=self.pdx)
        self.result_data_label1 = Label(self.init_window_name, text="获取的返回值:")
        self.result_data_label1.grid(row=self.row_4, column=self.column_2,sticky=N+W,padx=self.pdx)

        #row 5
        self.log_data_Text = Text(self.init_window_name,height=self.text_height)  # 日志框
        self.log_data_Text.grid(row=self.row_5, column=self.column_1, columnspan=self.row3_columnspan_1,rowspan=self.row_rowspan_2,sticky=N+W,padx=self.pdx)
        self.result_data_Text1 = Text(self.init_window_name,height=self.text_height)#处理结果展示
        self.result_data_Text1.grid(row=self.row_5, column=self.column_2, rowspan=self.row_rowspan_2, columnspan=self.row3_columnspan_2,sticky=N+W,padx=self.pdx)

        #事件件绑定
        self.init_tree.bind("<Double-1>", self.onDBClick)

    def onDBClick(self,event):
        try:
            item = self.init_tree.selection()[0]
            modelname=self.init_tree.item(item, "values")
            print ("you clicked on name is :{0} ".format(modelname[0]))
            self.getOneMessage(modelname[0])
            self.write_log_to_Text("INFO: 查看接口 【{0}】的信息".format(modelname[0]))
            self.har_path_input2.insert(0,modelname[0])
        except Exception as e:
            self.write_log_to_Text("ERROR: {0}".format(e))
        
    
    def openfiles(self):
      try:
            harfilename = filedialog.askopenfilename(title='打开Har文件', filetypes=[('har', '*.har'), ('All Files', '*')],initialdir='./')
            self.har_path_input.insert(0,harfilename)
            self.write_log_to_Text("INFO: 打开文件: {0}".format(harfilename))
            self.HarTool=HarTool(harfilename)
            #清空表格
            table_items=self.init_tree.get_children()
            for item in table_items:
                self.init_tree.delete(item)
            i=0
            for name in self.HarTool.harfile.keys():
                self.init_tree.insert('',i,values=(name))
      except Exception as e:
            self.write_log_to_Text("ERROR: {0}".format(e))
      

    def getOneMessage(self,name):
        try:
            self.write_log_to_Text("INFO: 获取一条返回值模型信息")
            result,res=self.HarTool.getMessage(name)
            self.result_data_Text.delete(1.0,END)
            self.result_data_Text.insert(1.0,json.dumps(result, sort_keys=True, indent=4, separators=(',', ': '),ensure_ascii=False))
            self.result_data_Text1.delete(1.0,END)
            self.result_data_Text1.insert(1.0,json.dumps(res, sort_keys=True, indent=4, separators=(',', ': '),ensure_ascii=False))
    
        except Exception as e:
            self.write_log_to_Text("ERROR: {0}".format(e))
        
    def createAllCase(self):
        try:
            self.write_log_to_Text("INFO: 开始为全部接口信息创建测试用例")
            self.HarTool.createALLCase()
            self.write_log_to_Text("INFO: 全部用例创建结束")
        except Exception as e:
            self.write_log_to_Text("ERROR: {0}".format(e))

    #获取当前时间
    def get_current_time(self):
        current_time = time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(time.time()))
        return current_time
    
    def createOneCase(self):
        try:
            req_str=json.loads(self.result_data_Text.get(1.0,END))
            self.write_log_to_Text("INFO: 开始生成单条测试用例 {0}".format(req_str['name']))
            res_str=json.loads(self.result_data_Text1.get(1.0,END))
            self.HarTool.createTestCase(req_str,res_str)
            self.write_log_to_Text("INFO: 成功生成用例")
        except Exception as e:
            self.write_log_to_Text("ERROR: {0}".format(e))
        
    #日志动态打印
    def write_log_to_Text(self,logmsg):
        global LOG_LINE_NUM
        current_time = self.get_current_time()
        logmsg_in = str(current_time) +" " + str(logmsg) + "\n"      #换行
        if LOG_LINE_NUM <= 7:
            self.log_data_Text.insert(END, logmsg_in)
            LOG_LINE_NUM = LOG_LINE_NUM + 1
        else:
            self.log_data_Text.delete(1.0,2.0)
            self.log_data_Text.insert(END, logmsg_in)

def gui_start():
    init_window = Tk()              #实例化出一个父窗口
    ZMJ_PORTAL = ApiTest_GUI(init_window)
    # 设置根窗口默认属性
    ZMJ_PORTAL.set_init_window()
    # ZMJ_PORTAL.initData()
    init_window.mainloop()          #父窗口进入事件循环，可以理解为保持窗口运行，否则界面不展示
    
if __name__ == "__main__":

    gui_start()





#encoding=utf-8
import os
import logging
import BearSki.report.LocalReportRunner as rut
from BearSki.CommonData import SkiGlobalData
from BearSki.utils.singleton import Singleton
from BearSki.utils.arguments import runArg

class LoggerBaseConfig(object):
   
    def __init__(self):
       
        self.level=get_level()
        self.filename=get_log_path()
        self._initlogger()

    def _initlogger(self):
        # pass
        rflogger=SkiLogger('RobotFramework')
    def _htmlRunner_logset(self):
        logging.basicConfig(stream=rut.stdout_redirector,
        format='[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s'
        )
        
@Singleton
class SkiLogger(object):
    def __init__(self, name=''):
        self.logger = logging.getLogger(name)
        self.loglevel=get_level()
        self.logger.setLevel(self.loglevel)
        fmt = logging.Formatter('[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s')
        # 设置CMD日志
        sh = logging.StreamHandler()
        sh.setFormatter(fmt)
        sh.setLevel(self.loglevel)
        # 由于logging 的filehandler 与 stream 不能共存所以需要根据不同模式设置日志输出方式。
        if runArg().report_mode =='html':
            logging.basicConfig(stream=rut.stdout_redirector,
            format='[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s')
        if runArg().report_mode =='text':
            # 设置文件日志
            #logfile_path=SkiGlobalData().get_global_data("logfile_path")
            logfile_path=get_log_path()
            fh = logging.FileHandler(logfile_path)
            fh.setFormatter(fmt)
            fh.setLevel(self.loglevel)
            self.logger.addHandler(sh)
            self.logger.addHandler(fh)

    def debug(self, message):
        self.logger.debug(message)

    def info(self, message):
        self.logger.info(message)

    def warn(self, message):
        self.logger.warn(message)

    def error(self, message):
        self.logger.error(message)

    def critical(self, message):
        self.logger.critical(message)
        
def get_level():
    reloglevel=get_logging_level(SkiGlobalData().get_global_data("log_level"))
    return reloglevel

def get_logging_level(levelmessage):

        if levelmessage.upper()=='DEBUG':
            return logging.DEBUG
        elif levelmessage.upper()=='ERROR':
            return logging.ERROR
        elif levelmessage.upper()=='WARNING':
            return logging.WARNING
        elif levelmessage.upper()=='CRITICAL':
            return logging.CRITICAL
        elif levelmessage.upper()=='FATAL':
            return logging.FATAL
        else:
            return logging.INFO

def get_log_path():
    config_json=SkiGlobalData().get_global_data("logfile_path")
    (logfile_path, logfile_name) = os.path.split(config_json)
    if logfile_path and logfile_name:
            isExists=os.path.exists(logfile_path)
            if not isExists:
                os.makedirs(logfile_path) 
    return config_json

# if __name__ == '__main__':
#     logger = Logger('test')
#     logger.debug('debug信息')
#     logger.info('info信息')
#     logger.war('warning信息')
#     logger.error('error信息')
#     logger.critical('critical信息')
